/*
    dtaus.h - Datentraegeraustausch mit einer Bank
    Copyright (c) 1996,8  Martin Schulze <joey@artis.uni-oldenburg.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111, USA.

    $Id: dtaus.h,v 1.3 2004/08/06 20:23:12 joey Exp $
 */

#ifndef _DTAUS_H_
#define _DTAUS_H_

void dtaus2control (char *cdtaus, char *ccontrol);

int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck, char *latex);

#endif /* _DTAUS_H_ */
